<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}

class LaStudio_Shortcodes_Param{

    public static $instance = null;

    public static function register() {
        if ( null === self::$instance ) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct(){

        vc_add_shortcode_param('la_column', array($this, 'columnResponsiveCallBack') );
        vc_add_shortcode_param('la_number' , array($this, 'laNumberCallBack' ));
        vc_add_shortcode_param('la_heading' , array($this, 'headingCallBack' ));
        vc_add_shortcode_param('datetimepicker' , array($this, 'datetimePickerCallBack' ) );
        vc_add_shortcode_param('gradient' , array($this, 'gradient_picker' ) );
        vc_add_shortcode_param('la_slides_navigation' , array($this, 'slides_navigation' ) );
        vc_add_shortcode_param('la_hotspot_image_preview' , array($this, 'hotspot_image_preview' ) );
    }

    public function columnResponsiveCallBack($settings, $value){
        $unit = $settings['unit'];
        $medias = $settings['media'];

        if(is_numeric($value)){
            $value = "lg:".$value . $unit.';';
        }

        $uid = 'lastudio-responsive-'. rand(1000, 9999);

        $require = sprintf(
            '<div class="simplify"><span class="la-vc-icon"><div class="la-vc-tooltip simplify-options">%s</div><i class="simplify-icon dashicons dashicons-arrow-right-alt2"></i></span></div>',
            __('Responsive Options', 'la-studio')
        );
        $html  = '<div class="lastudio-responsive-wrapper" id="'.$uid.'"><div class="lastudio-responsive-items">';

        foreach($medias as $key => $default_value ) {

            switch ($key) {
                case 'xlg':
                    $html .= $this->getParamMedia(
                        'optional',
                        '<i class="fa fa-desktop"></i>',
                        __('Large Desktop', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );
                    break;

                case 'lg':
                    $html .= $this->getParamMedia(
                        'required',
                        '<i class="dashicons dashicons-desktop"></i>',
                        __('Desktop', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );
                    $html .= $require;
                    break;

                case 'md':
                    $html .= $this->getParamMedia(
                        'optional',
                        '<i class="dashicons dashicons-tablet" style="transform: rotate(90deg);"></i>',
                        __('Tablet', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );

                    break;

                case 'sm':
                    $html .= $this->getParamMedia(
                        'optional',
                        '<i class="dashicons dashicons-tablet"></i>',
                        __('Tablet Portrait', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );
                    break;

                case 'xs':
                    $html .= $this->getParamMedia(
                        'optional',
                        '<i class="dashicons dashicons-smartphone" style="transform: rotate(90deg);"></i>',
                        __('Mobile Landscape', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );
                    break;
                case 'mb':
                    $html .= $this->getParamMedia(
                        'optional',
                        '<i class="dashicons dashicons-smartphone"></i>',
                        __('Mobile', 'la-studio'),
                        $default_value,
                        $unit,
                        $key
                    );
                    break;
            }
        }
        $html .= '</div>';
        $html .= '<div class="lastudio-unit-section"><label>'.$unit.'</label></div>';
        $html .= '<input type="hidden" data-unit="'.$unit.'"  name="'.$settings['param_name'].'" class="wpb_vc_param_value lastudio-responsive-value '.$settings['param_name'].' '.$settings['type'].'_field" value="'.$value.'" />';
        $html .= '</div>';
        $html .= '<script type="text/javascript">jQuery("#'.$uid.'").trigger("vc_param.la_columns")</script>';
        return $html;
    }

    public function laNumberCallBack($settings, $value){
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $type = isset($settings['type']) ? $settings['type'] : '';
        $min = isset($settings['min']) ? $settings['min'] : '';
        $max = isset($settings['max']) ? $settings['max'] : '';
        $step = isset($settings['step']) ? $settings['step'] : '';
        $suffix = isset($settings['suffix']) ? $settings['suffix'] : '';
        $class = isset($settings['class']) ? $settings['class'] : '';
        $output = '<input type="number" min="'.$min.'" max="'.$max.'" step="'.$step.'" class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '" value="'.$value.'" style="max-width:100px; margin-right: 10px;" />'.$suffix;
        return $output;
    }

    public function headingCallBack($settings, $value){
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $class = isset($settings['class']) ? $settings['class'] : '';
        $text = isset($settings['text']) ? $settings['text'] : '';
        $output = '<h4 class="wpb_vc_param_value '.$class.'">'.$text.'</h4>';
        $output .= '<input type="hidden" name="'.$param_name.'" class="wpb_vc_param_value lastudio-param-heading '.$param_name.' '.$settings['type'].'_field" value="'.$value.'" />';
        return $output;
    }

    public function datetimePickerCallBack($settings, $value){
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $type = isset($settings['type']) ? $settings['type'] : '';
        $class = isset($settings['class']) ? $settings['class'] : '';
        $uni = uniqid('datetimepicker-'.rand());
        $output = '<div id="date-time-'.$uni.'" class="elm-datetime"><input data-format="yyyy/MM/dd hh:mm:ss" readonly class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '" style="width:258px;" value="'.$value.'"/><span class="add-on">
                        <span class="dashicons-before dashicons-calendar"></span>
                    </span></div>';
        $output .= '<script type="text/javascript">
				jQuery(document).ready(function(){
					jQuery("#date-time-'.$uni.'").datetimepicker();
				})
				</script>';
        return $output;
    }

    private function getParamMedia($class, $icon, $tip, $default_value, $unit, $data_id){
        return sprintf(
            '<div class="la-responsive-item %1$s %2$s"><span class="la-vc-icon"><div class="la-vc-tooltip %1$s %2$s">%3$s</div>%4$s</span><input type="text" class="la-responsive-input" data-default="%5$s" data-unit="%6$s" data-id="%2$s"/></div>',
            esc_attr($class),
            esc_attr($data_id),
            esc_html($tip),
            $icon,
            esc_attr($default_value),
            esc_attr($unit)
        );
    }

    public function gradient_picker($settings, $value) {
        $dependency = '';
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $type = isset($settings['type']) ? $settings['type'] : '';
        $color1 = isset($settings['color1']) ? $settings['color1'] : ' ';
        $color2 = isset($settings['color2']) ? $settings['color2'] : ' ';
        $class = isset($settings['class']) ? $settings['class'] : '';

        $dependency_element = $settings['dependency']['element'];
        $dependency_value = $settings['dependency']['value'];
        $dependency_value_json =  json_encode($dependency_value);

        $uni = uniqid();
        $output = '<div class="vc_ug_control" data-uniqid="'.$uni.'" data-color1="'.$color1.'" data-color2="'.$color2.'">';
        $output .= '<select id="grad_type'.$uni.'" class="grad_type" data-uniqid="'.$uni.'">
				<option value="vertical">'.__('Vertical', 'la-studio').'</option>
				<option value="horizontal">'.__('Horizontal', 'la-studio').'</option>
				<option value="custom">'.__('Custom', 'la-studio').'</option>
			</select>
			<div id="grad_type_custom_wrapper'.$uni.'" class="grad_type_custom_wrapper" style="display:none;"><input type="number" id="grad_type_custom'.$uni.'" placeholder="45" data-uniqid="'.$uni.'" class="grad_custom" style="width: 200px; margin-bottom: 10px;"/> deg</div>';
        $output .= '<div class="wpb_element_label" style="margin-top: 10px;">'.__('Choose Colors', 'la-studio').'</div>';
        $output .= '<div class="grad_hold" id="grad_hold'.$uni.'"></div>';
        $output .= '<div class="grad_trgt" id="grad_target'.$uni.'"></div>';

        $output .= '<input id="grad_val'.$uni.'" class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . ' vc_ug_gradient" name="' . $param_name . '"  style="display:none"  value="'.$value.'" '.$dependency.'/></div>';

        ?>
        <script type="text/javascript">
            jQuery(document).ready(function(){
                var dependency_element = '<?php echo $dependency_element ?>';
                var dependency_values = jQuery.parseJSON('<?php echo $dependency_value_json ?>');
                var dependency_values_array = jQuery.map(dependency_values, function(el) { return el; });

                var get_depend_value = jQuery('.'+dependency_element).val();

                jQuery('.grad_type').change(function(){
                    var uni = jQuery(this).data('uniqid');
                    var hid = "#grad_hold"+uni;
                    var did = "#grad_target"+uni;
                    var cid = "#grad_type_custom"+uni;
                    var tid = "#grad_val"+uni;
                    var cid_wrapper = "#grad_type_custom_wrapper"+uni;
                    var orientation = jQuery(this).children('option:selected').val();

                    if(orientation == 'custom')
                    {
                        jQuery(cid_wrapper).show();
                    }
                    else
                    {
                        jQuery(cid_wrapper).hide();
                        if(orientation == 'vertical')
                            var ori = 'top';
                        else
                            var ori = 'left';

                        jQuery(hid).data('ClassyGradient').setOrientation(ori);
                        var newCSS = jQuery(hid).data('ClassyGradient').getCSS();

                        jQuery(tid).val(newCSS);
                    }

                });

                jQuery('.grad_custom').on('keyup',function() {
                    var uni = jQuery(this).data('uniqid');
                    var hid = "#grad_hold"+uni;
                    var gid = "#grad_type"+uni;
                    var tid = "#grad_val"+uni;
                    var orientation = jQuery(this).val()+'deg';
                    jQuery(hid).data('ClassyGradient').setOrientation(orientation);
                    var newCSS = jQuery(hid).data('ClassyGradient').getCSS();
                    jQuery(tid).val(newCSS);
                });

                function gradient_pre_defined(dependency_element, dependency_values_array){
                    jQuery('.vc_ug_control').each(function(){
                        var uni = jQuery(this).data('uniqid');
                        var hid = "#grad_hold"+uni;
                        var did = "#grad_target"+uni;
                        var tid = "#grad_val"+uni;
                        var oid = "#grad_type"+uni;
                        var cid = "#grad_type_custom"+uni;
                        var cid_wrapper = "#grad_type_custom_wrapper"+uni;
                        var orientation = jQuery(oid).children('option:selected').val();
                        var prev_col = jQuery(tid).val();

                        var is_custom = 'false';

                        if(prev_col!='')
                        {
                            if(prev_col.indexOf('-webkit-linear-gradient(top,') != -1)
                            {
                                var p_l = prev_col.indexOf('-webkit-linear-gradient(top,');
                                prev_col = prev_col.substring(p_l+28);
                                p_l = prev_col.indexOf(');');
                                prev_col = prev_col.substring(0,p_l);
                                orientation = 'vertical';
                            }
                            else if(prev_col.indexOf('-webkit-linear-gradient(left,') != -1)
                            {
                                var p_l = prev_col.indexOf('-webkit-linear-gradient(left,');
                                prev_col = prev_col.substring(p_l+29);
                                p_l = prev_col.indexOf(');');
                                prev_col = prev_col.substring(0,p_l);
                                orientation = 'horizontal';
                            }
                            else
                            {
                                var p_l = prev_col.indexOf('-webkit-linear-gradient(');

                                var subStr = prev_col.match("-webkit-linear-gradient((.*));background: -o");

                                var prev_col = subStr[1].replace(/\(|\)/g, '');

                                var temp_col = prev_col;

                                var t_l = temp_col.indexOf('deg');
                                var deg = temp_col.substring(0,t_l);

                                prev_col = prev_col.substring(t_l+4, prev_col.length);

                                jQuery(cid).val(deg);
                                jQuery(cid_wrapper).show();
                                orientation = 'custom';
                                is_custom = 'true';
                            }
                        }
                        else
                        {
                            prev_col ="#e3e3e3 0%";
                        }

                        jQuery(oid).children('option').each(function(i,opt){
                            if(opt.value == orientation)
                                jQuery(this).attr('selected',true);

                        });

                        if(is_custom == 'true')
                            orientation = deg+'deg';
                        else
                        {
                            if(orientation == 'vertical')
                                orientation = 'top';
                            else
                                orientation = 'left';
                        }

                        jQuery(hid).ClassyGradient({
                            width:350,
                            height:25,
                            orientation : orientation,
                            target:did,
                            gradient: prev_col,
                            onChange: function(stringGradient,cssGradient) {

                                var depend = uvc_gradient_verfiy_depedant(dependency_element, dependency_values_array);

                                cssGradient = cssGradient.replace('url(data:image/svg+xml;base64,','');
                                var e_pos = cssGradient.indexOf(';');
                                cssGradient = cssGradient.substring(e_pos+1);
                                if(jQuery(tid).parents('.wpb_el_type_gradient').css('display')=='none'){
                                    //jQuery(tid).val('');
                                    cssGradient='';
                                }
                                if(depend)
                                    jQuery(tid).val(cssGradient);
                                else
                                    jQuery(tid).val('');
                            },
                            onInit: function(cssGradient){
                                //console.log(jQuery(tid).val())
                                //check_for_orientation();

                            }
                        });
                        jQuery('.colorpicker').css('z-index','999999');
                    })
                }

                gradient_pre_defined(dependency_element, dependency_values_array);

                jQuery('.'+dependency_element).on('change',function(){
                    var depend = uvc_gradient_verfiy_depedant(dependency_element, dependency_values_array);
                    jQuery('.vc_ug_control').each(function(){
                        var uni = jQuery(this).data('uniqid');
                        var tid = "#grad_val"+uni;
                        if(depend === false)
                            jQuery(tid).val('');
                        else
                            gradient_pre_defined(dependency_element, dependency_values_array);
                    });

                });

                function uvc_gradient_verfiy_depedant(dependency_element, dependency_values_array) {
                    var get_depend_value = jQuery('.'+dependency_element).val();
                    if(jQuery.inArray( get_depend_value, dependency_values_array ) !== -1)
                        return true;
                    else
                        return false;
                }

            })
        </script>
        <?php
        return $output;
    }

    public function slides_navigation( $settings, $value ){
        $uid = uniqid();
        $param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
        $type = isset($settings['type']) ? $settings['type'] : '';
        $class = isset($settings['class']) ? $settings['class'] : '';
        if($param_name == "next_icon"){
            $icons = array('laslick-arrow-right','laslick-arrow-right2','laslick-arrow-right3','laslick-arrow-right4','laslick-arrow-right6');
        }
        if($param_name == "prev_icon"){
            $icons = array('laslick-arrow-left','laslick-arrow-left2','laslick-arrow-left3','laslick-arrow-left4','laslick-arrow-left6');
        }

        if($param_name == "dots_icon"){
            $icons = array('laslick-checkbox-unchecked','laslick-checkbox-partial','laslick-stop','laslick-radio-checked','laslick-radio-unchecked','laslick-record');
        }
        $output = '<input type="hidden" name="'.esc_attr( $param_name ).'" class="wpb_vc_param_value '.esc_attr( $param_name ).' '.esc_attr( $type ).' '.esc_attr( $class ).'" value="'.esc_attr( $value ).'" id="trace-'.esc_attr( $uid ).'"/>';
        $output .='<div id="icon-dropdown-'.esc_attr( $uid ).'" >';
        $output .= '<ul class="icon-list">';
        $n = 1;
        foreach($icons as $icon) {
            $selected = ($icon == $value) ? 'class="selected"' : '';
            $output .= '<li '.$selected.' data-ac-icon="'.esc_attr( $icon ).'"><i class="ult-icon '.esc_attr( $icon ).'"></i><label class="ult-icon">'.esc_html( $icon ).'</label></li>';
            $n++;
        }
        $output .='</ul>';
        $output .='</div>';
        $output .= '<script type="text/javascript">
					jQuery("#icon-dropdown-'.esc_attr( $uid ).' li").click(function() {
						jQuery(this).attr("class","selected").siblings().removeAttr("class");
						var icon = jQuery(this).attr("data-ac-icon");
						jQuery("#trace-'.esc_attr( $uid ).'").val(icon);
						jQuery(".icon-preview-'.esc_attr( $uid ).'").html("<i class=\'laslick-icon "+icon+"\'></i>");
					});
			</script>';
        $output .= '<style type="text/css">';
        $output .= 'ul.icon-list li {
							display: inline-block;
							float: left;
							padding: 5px;
							border: 1px solid #ddd;
							font-size: 18px;
							width: 18px;
							height: 18px;
							line-height: 18px;
							margin: 0 auto;
						}
						ul.icon-list li label.ult-icon {
							display: none;
						}
						.ult-icon-preview {
							padding: 5px;
							font-size: 24px;
							border: 1px solid #ddd;
							display: inline-block;
						}
						ul.icon-list li.selected {
							background: #3486D1;
							padding: 10px;
							margin: 0 -1px;
							margin-top: -7px;
							color: #fff;
							font-size: 24px;
							width: 24px;
							height: 24px;
						}';
        $output .= '</style>';
        return $output;
    }

    public function hotspot_image_preview( $settings, $value ){
        $image_output = null;

        if(!empty($value)) $image_output = '<img src="'. esc_attr($value) . '" alt="preview" />';

        return '<div id="la_image_with_hotspots_preview"><input name="' . esc_attr( $settings['param_name'] ) . '" type="hidden" class="wpb_vc_param_value ' . esc_attr( $settings['param_name'] ) . '" value="'.esc_attr($value).'" /> '.$image_output. '</div>';
    }

}